/**
  ******************************************************************************
  * @file    stm32l0xx_lppuart_msp.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   Product specific implementation
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "stm32xx_lppuart_conf.h"

/* External variables --------------------------------------------------------*/
/* Private typedef -----------------------------------------------------------*/
/* Private defines -----------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/
/* Private macros ------------------------------------------------------------*/
/* Public functions ----------------------------------------------------------*/

/**
  * @brief  Initialize DMA
  *
  * @param  hdma_tx      : pointer to the Tx DMA handle
  *
  * @param  hdma_rx      : pointer to the Rx DMA handle
  *
  * @retval None
  */
void LPPUART_msp_dma_set_config(DMA_HandleTypeDef *hdma_tx, DMA_HandleTypeDef *hdma_rx)
{
	/**
	 * Configure TX path
	 */
	hdma_tx->Init.PeriphInc = DMA_PINC_DISABLE;
	hdma_tx->Init.MemInc = DMA_MINC_ENABLE;
	hdma_tx->Init.Mode = DMA_NORMAL;
	hdma_tx->Init.Priority = DMA_PRIORITY_VERY_HIGH;
	hdma_tx->Init.MemDataAlignment = DMA_MDATAALIGN_BYTE;
	hdma_tx->Init.PeriphDataAlignment = DMA_PDATAALIGN_BYTE;
	hdma_tx->Init.Direction = DMA_MEMORY_TO_PERIPH;
	hdma_tx->Init.Request = DMA_USART_TX_REQ;

	/**
	 * Configure RX path
	 */
	hdma_rx->Init.PeriphInc = DMA_PINC_DISABLE;
	hdma_rx->Init.MemInc = DMA_MINC_ENABLE;
	hdma_rx->Init.Mode = DMA_NORMAL;
	hdma_rx->Init.Priority = DMA_PRIORITY_VERY_HIGH;
	hdma_rx->Init.MemDataAlignment = DMA_MDATAALIGN_BYTE;
	hdma_rx->Init.PeriphDataAlignment = DMA_PDATAALIGN_BYTE;
	hdma_rx->Init.Direction = DMA_PERIPH_TO_MEMORY;
	hdma_rx->Init.Request = DMA_USART_RX_REQ;

    return;
}

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
