/**
  ******************************************************************************
  * @file    stm32xx_nvm.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   Header for stm32xx_nvm.c module
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __STM32xx_NVM_H
#define __STM32xx_NVM_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "stm32xx_nvm_conf.h"

/* Exported types ------------------------------------------------------------*/
 typedef enum
 {
 	eNVM_Write,
 	eNVM_Clear
 } eNVM_Operation_t;

 typedef enum{
 	 eNVM_HSclkDisable,
 	 eNVM_HSclkEnable
 }eNVM_HSclkMode_t;


/* Exported constants --------------------------------------------------------*/

/**
 * Maximum number of operations (Write/Erase) to be queued in the driver
 */
#define	NVM_OPERATION_QUEUE_SIZE		30

 /**
  * NVM Base address to store the data - Bank2 - The first 1120 bytes are reserved to BLE
  */
#define NVM_BASE_ADDRESS				0x08080460

 /**
  * Preempt priority
  * NVM Interrupt priority
  */
#define NVM_IT_PREEMPTPRIORITY					3

 /**
  * Sub priority
  * NVM Interrupt priority
  */
#define NVM_IT_SUBPRIORITY					0

 /**
  * NVM Interrupt handler ID
  * It shall be type of IRQn_Type
  */
#define	NVIC_NVM_HANDLER_ID		FLASH_IRQn

 /**
  *  Define a critical section in the NVM driver
  *  The NVM Driver does not support the API to be nested
  *  The  Application shall either:
  *  	a) Ensure this will never happen (When using an OS, there could be one NVM process)
  *  	b) Define the critical section
  *  The default implementations is masking all interrupts using the PRIMASK bit
  *  When the application is implementing low latency interrupts that would not support to be masked out,
  *  the critical section may use the basepri register to mask out only interrupt that have lower priority than those interrupts
  *  In that case, the application shall not call the NVM API interface within these interrupt handlers.
  */
#define NVM_ENTER_CRITICAL_SECTION	__disable_irq()	/**< Enter the critical section */
#define NVM_EXIT_CRITICAL_SECTION	__enable_irq()	/**< Exit the critical section */


/* Exported macros -----------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
 void NVM_Init(void);
 void NVM_Register(uint32_t *NVMAddressBlock, uint16_t BlockSize);
 void NVM_Read(uint8_t *UserAddress, uint8_t *NVMAddress, uint16_t Size);
 void NVM_Operation(eNVM_Operation_t eOperation, uint8_t *UserAddress, uint8_t *NVMAddress, uint16_t Size);
 void NVM_HSclkRequest(eNVM_HSclkMode_t eHSclkMode);
 void NVM_Flash_Interrupt_handler(void);

#ifdef __cplusplus
}
#endif

#endif /*__STM32xx_NVM_H */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
