/**
  ******************************************************************************
  * @file    ble_nvm.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   Wrapper between the BLE NVM interface and the NVM driver
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */


/**
  * @note	This file contains the mapping of the BLE module NVM interface to the NVM driver
  */

/* Includes ------------------------------------------------------------------*/
#include "pstorage.h"
#include "app_error.h"
#include "stm32xx_nvm_conf.h"

/* Private defines -----------------------------------------------------------*/

/**
 * Base address to store the BLE parameters
 */
#define BLE_NVM_BASE_ADDRESS		0x08080000

/* Private variables ---------------------------------------------------------*/
static uint16_t aBlockSizeList[3];				/**< Only 3 BLE modules Id supported */
static uint8_t	ModuleId;
static uint8_t *pCurrentPointerToNVMLocation;

/* Public functions ----------------------------------------------------------*/

uint32_t pstorage_init(void)
{
	ModuleId = 0;
	pCurrentPointerToNVMLocation = (uint8_t *)BLE_NVM_BASE_ADDRESS;

    return NRF_SUCCESS;
}

uint32_t pstorage_register(pstorage_module_param_t * p_module_param,
                           pstorage_handle_t       * p_block_id)
{
	p_block_id->block_id = (uint32_t)pCurrentPointerToNVMLocation;
	(p_block_id->module_id) = ModuleId;
	 /*
	  * store the size of the allocated block to be used in the API pstorage_block_identifier_get()
	  */
	aBlockSizeList[ModuleId] = p_module_param->block_size;

	pCurrentPointerToNVMLocation = pCurrentPointerToNVMLocation + (p_module_param->block_size)*(p_module_param->block_count);
	ModuleId++;			/**< increment the module Id for the next registration */

    return NRF_SUCCESS;
}

uint32_t pstorage_block_identifier_get(pstorage_handle_t * p_base_id,
                                       pstorage_size_t     block_num,
                                       pstorage_handle_t * p_block_id)
{
    
	p_block_id->block_id = (p_base_id->block_id) + (block_num * aBlockSizeList[p_base_id->module_id]);

    return NRF_SUCCESS;
}

uint32_t pstorage_store(pstorage_handle_t * p_dest,
                        uint8_t           * p_src,
                        pstorage_size_t     size,
                        pstorage_size_t     offset)
{
	NVM_Operation(eNVM_Write, p_src, (uint8_t *)(p_dest->block_id) + offset, size);

    return NRF_SUCCESS;
}

uint32_t pstorage_load(uint8_t *           p_dest,
                       pstorage_handle_t * p_src,
                       pstorage_size_t     size,
                       pstorage_size_t     offset)
{
	NVM_Read(p_dest, (uint8_t *)(p_src->block_id) + offset, size);

    return NRF_SUCCESS;
}

uint32_t pstorage_clear(pstorage_handle_t * p_dest, pstorage_size_t size)
{
	NVM_Operation(eNVM_Clear, 0, (uint8_t *)(p_dest->block_id), aBlockSizeList[p_dest->module_id] * size);

    return NRF_SUCCESS;
}

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
