/**
  ******************************************************************************
  * @file    ble_timer.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   Wrapper between the BLE timer interface and the Timer server
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */


/**
  * @note	This file contains the mapping of the BLE module TIMER interface to the TIMER server
  */

/* Includes ------------------------------------------------------------------*/
#include "ble_timer.h"
#include "nrf_error.h"
#include "stm32xx_timerserver_conf.h"

/* Public functions ----------------------------------------------------------*/

uint32_t ble_timer_create(ble_timer_id_t *            p_timer_id,
                          ble_timer_mode_t            mode,
                          ble_timer_timeout_handler_t timeout_handler)
{
    TIMER_Create(	eTimerModuleID_BLE, (uint8_t *)p_timer_id, (eTIMER_TimerMode_t)mode, (pf_TIMER_TimerCallBack_t)timeout_handler);
    return NRF_SUCCESS;
}

uint32_t ble_timer_start(ble_timer_id_t timer_id, uint32_t timeout_ms, void * p_context)
{
    TIMER_Start(timer_id, timeout_ms);		
    return NRF_SUCCESS;               
}

uint32_t ble_timer_stop(ble_timer_id_t timer_id)
{
    TIMER_Delete(timer_id);
    return NRF_SUCCESS;
}

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
