/**
  ******************************************************************************
  * @file    msp_main.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   This is the MCU dependant application implementation
  *
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "app_conf.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Public functions ---------------------------------------------------------*/

/**
  * @brief  Switch ON resources needed for BLE operation
  *
  * @note
  *
  * @param  None
  *
  * @retval None
  */
void UART_BLE_Init(void)
{
	/*
	 * Swich ON all IO blocks used by the UART
	 */

	if (USART_GPIO_AHB_CLK && RCC_IOPENR_GPIOAEN)
	{
		__GPIOA_CLK_ENABLE();
	}

	if (USART_GPIO_AHB_CLK && RCC_IOPENR_GPIOBEN)
	{
	__GPIOB_CLK_ENABLE();
	}

	if (USART_GPIO_AHB_CLK && RCC_IOPENR_GPIOCEN)
	{
	__GPIOC_CLK_ENABLE();
	}

	if (USART_GPIO_AHB_CLK && RCC_IOPENR_GPIODEN)
	{
	__GPIOD_CLK_ENABLE();
	}

	__DMA1_CLK_ENABLE();	/**< Switch ON DMA1 clock */

	__SYSCFG_CLK_ENABLE();	/**< Switch ON SYSCFG APB Clock */

#if (USART_SELECTED == BLE_ON_USART1)
	__USART1_CLK_ENABLE();	/**< Switch ON USART1 for BLE */
#elif (USART_SELECTED == BLE_ON_USART2)
	__USART2_CLK_ENABLE();	/**< Switch ON USART2 for BLE */
#elif (USART_SELECTED == BLE_ON_LPUART)
	__LPUART1_CLK_ENABLE();	/**< Switch ON LPUART1 for BLE */
#endif

	__PWR_CLK_ENABLE();		/**< Enable PWR clock */

	return;
}

/**
  * @brief  Configure the system clock
  *
  * @note	This API configures
  * 		- The system clock source
  * 		- The AHBCLK, APBCLK dividers
  * 		- The flash latency
  * 		- The PLL settings (when required)
  *
  * @param  None
  * @retval None
  */
void SystemClock_Config(void)
{
	RCC_OscInitTypeDef RCC_OscInitStruct;
	RCC_ClkInitTypeDef RCC_ClkInitStruct;

	/**
	 * Enable clock on PWR block
	 * This is used to setup registers when entering low power mode
	 */
	__PWR_CLK_ENABLE();

	/**
	 * Set voltage scaling range
	 */
	#if (HCLK_32MHZ == 1)
	__HAL_PWR_VOLTAGESCALING_CONFIG(PWR_REGULATOR_VOLTAGE_SCALE1);

	/**
	 *  Enable HSI oscillator and configure the PLL to reach the max system frequency (32MHz)
	 *  when using HSI oscillator as PLL clock source.
	 */
	RCC_OscInitStruct.OscillatorType = RCC_OSCILLATORTYPE_HSI;
	RCC_OscInitStruct.HSICalibrationValue = 0x10;
	RCC_OscInitStruct.HSIState = RCC_HSI_ON;
	RCC_OscInitStruct.PLL.PLLState = RCC_PLL_ON;
	RCC_OscInitStruct.PLL.PLLSource = RCC_PLLSOURCE_HSI;
	RCC_OscInitStruct.PLL.PLLMUL = RCC_PLLMUL_4;
	RCC_OscInitStruct.PLL.PLLDIV = RCC_PLLDIV_2;

	HAL_RCC_OscConfig(&RCC_OscInitStruct);

	/**
	 *  Select PLL as system clock source and configure the HCLK, PCLK1 and PCLK2 clocks dividers.
	 *  The SysTick 1 msec interrupt is required for the HAL process (Timeout management); by default
	 *  the configuration is done using the HAL_Init() API, and when the system clock configuration
	 *  is updated the SysTick configuration will be adjusted by the HAL_RCC_ClockConfig() API.
	 */
	RCC_ClkInitStruct.ClockType = (RCC_CLOCKTYPE_SYSCLK | RCC_CLOCKTYPE_HCLK | RCC_CLOCKTYPE_PCLK1 | RCC_CLOCKTYPE_PCLK2);
	RCC_ClkInitStruct.SYSCLKSource = RCC_SYSCLKSOURCE_PLLCLK;
	RCC_ClkInitStruct.AHBCLKDivider = RCC_SYSCLK_DIV1;
	RCC_ClkInitStruct.APB1CLKDivider = RCC_HCLK_DIV4;
	RCC_ClkInitStruct.APB2CLKDivider = RCC_HCLK_DIV4;

	HAL_RCC_ClockConfig(&RCC_ClkInitStruct, FLASH_LATENCY_1);

	#else
	/**
	* Reset value is Range 2
	*/

	/**
	 *  Enable HSI oscillator and configure the system at 8MHz
	 */
	RCC_OscInitStruct.OscillatorType = RCC_OSCILLATORTYPE_HSI;
	RCC_OscInitStruct.HSICalibrationValue = 0x10;
	RCC_OscInitStruct.HSIState = RCC_HSI_ON;
	RCC_OscInitStruct.PLL.PLLState = RCC_PLL_OFF;

	HAL_RCC_OscConfig(&RCC_OscInitStruct);

	/**
	 *  Configure the HCLK, PCLK1 and PCLK2 clocks dividers  to get 8Mhz.
	 *  The SysTick 1 msec interrupt is required for the HAL process (Timeout management); by default
	 *  the configuration is done using the HAL_Init() API, and when the system clock configuration
	 *  is updated the SysTick configuration will be adjusted by the HAL_RCC_ClockConfig() API.
	 */
	RCC_ClkInitStruct.ClockType = (RCC_CLOCKTYPE_SYSCLK | RCC_CLOCKTYPE_HCLK | RCC_CLOCKTYPE_PCLK1 | RCC_CLOCKTYPE_PCLK2);
	RCC_ClkInitStruct.SYSCLKSource = RCC_SYSCLKSOURCE_HSI;
	RCC_ClkInitStruct.AHBCLKDivider = RCC_SYSCLK_DIV2;
	RCC_ClkInitStruct.APB1CLKDivider = RCC_SYSCLK_DIV1;
	RCC_ClkInitStruct.APB2CLKDivider = RCC_SYSCLK_DIV1;

	HAL_RCC_ClockConfig(&RCC_ClkInitStruct, FLASH_LATENCY_0);

	#endif

	return;
}

/**
  * @brief  Configure the system for power optimization
  *
  * @note	This API configures the system to be ready for low power mode
  * 		- Unused GPIO in Analog mode
  * 		- Fast Wakeup
  * 		- Verefint disabled in low power mode
  * 		- FLASH in low power mode
  *
  * @param  None
  * @retval None
  */
void SystemPower_Config(void)
{
	GPIO_InitTypeDef GPIO_InitStructure;

	/**
	 * Disable FLASH in SLEEP Mode
	 */
	__HAL_FLASH_SLEEP_POWERDOWN_ENABLE();

	/**
	 * Enable Ultra low power and Fast wakeup as vrefint is not used in that project
	 */
	HAL_PWREx_EnableUltraLowPower();
	HAL_PWREx_EnableFastWakeUp();

	/*
	 * Select HSI as system clock source after Wake Up from Stop mode
	 */
	__HAL_RCC_WAKEUPSTOP_CLK_CONFIG(RCC_StopWakeUpClock_HSI);

	/*
	 * Enable GPIOs clock
	 */
	__GPIOA_CLK_ENABLE();
  	__GPIOB_CLK_ENABLE();
  	__GPIOC_CLK_ENABLE();
  	__GPIOD_CLK_ENABLE();
  	__GPIOH_CLK_ENABLE();

  	/*
  	 * Configure all GPIO port pins in Analog mode with no pull
  	 */
  	GPIO_InitStructure.Mode = GPIO_MODE_ANALOG;
  	GPIO_InitStructure.Pull = GPIO_NOPULL;
  	GPIO_InitStructure.Pin = GPIO_PIN_All;
  	HAL_GPIO_Init(GPIOB, &GPIO_InitStructure);
  	HAL_GPIO_Init(GPIOC, &GPIO_InitStructure);
  	HAL_GPIO_Init(GPIOD, &GPIO_InitStructure);
  	HAL_GPIO_Init(GPIOH, &GPIO_InitStructure);

  	#if (JTAG_SUPPORTED == 1)
	GPIO_InitStructure.Pin = (GPIO_PIN_All ^ (GPIO_PIN_13 | GPIO_PIN_14));
	#endif
  	HAL_GPIO_Init(GPIOA, &GPIO_InitStructure);

  	/*
  	 * Disable GPIOs clock
  	 */
  	__GPIOA_CLK_DISABLE();
  	__GPIOB_CLK_DISABLE();
  	__GPIOC_CLK_DISABLE();
  	__GPIOD_CLK_DISABLE();
  	__GPIOH_CLK_DISABLE();

  	return;
}

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
