/**
  ******************************************************************************
  * @file    stm32l0xx_it.c 
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   Main Interrupt Service Routines.
  *          This file provides template for all exceptions handler and 
  *          peripherals interrupt service routine.
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "app_conf.h"
#include "stm32l0xx_nucleo.h"

/** @addtogroup STM32L0xx_HAL_Examples
  * @{
  */

/** @addtogroup UART_TwoBoards_ComPolling
  * @{
  */

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/******************************************************************************/
/*            Cortex-M0+ Processor Exceptions Handlers                         */
/******************************************************************************/

/**
  * @brief  This function handles NMI exception.
  * @param  None
  * @retval None
  */
void NMI_Handler(void)
{
}

/**
  * @brief  This function handles Hard Fault exception.
  * @param  None
  * @retval None
  */
void HardFault_Handler(void)
{
  /* Go to infinite loop when Hard Fault exception occurs */
  while (1)
  {
  }
}

/**
  * @brief  This function handles SVCall exception.
  * @param  None
  * @retval None
  */
void SVC_Handler(void)
{
}

/**
  * @brief  This function handles Debug Monitor exception.
  * @param  None
  * @retval None
  */
void DebugMon_Handler(void)
{
}

/**
  * @brief  This function handles PendSVC exception.
  * @param  None
  * @retval None
  */
void PendSV_Handler(void)
{
}

/**
  * @brief  This function handles SysTick Handler.
  * @param  None
  * @retval None
  */
void SysTick_Handler(void)
{
  HAL_IncTick();
}

/******************************************************************************/
/*                 STM32L0xx Peripherals Interrupt Handlers                   */
/*  Add here the Interrupt Handler for the used peripheral(s) (PPP), for the  */
/*  available peripheral interrupt handler's name please refer to the startup */
/*  file (startup_stm32l0xx.s).                                               */
/******************************************************************************/

/**
  * @brief  Mapping of the UART interrupt handler used for BLE
  *
  * @note
  *
  * @param  None
  *
  * @retval None
  */
#if (USART_SELECTED == BLE_ON_USART1)
void USART1_IRQHandler(void)
#elif (USART_SELECTED == BLE_ON_USART2)
void USART2_IRQHandler(void)
#elif (USART_SELECTED == BLE_ON_LPUART)
void RNG_LPUART1_IRQHandler(void)
#endif
{
	LPPUART_uart_handler();

	return;
}

/**
  * @brief  Mapping of the DMA RX interrupt used for BLE
  *
  * @note
  *
  * @param  None
  *
  * @retval None
  */
#if (USART_RX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL3)
void DMA1_Channel2_3_IRQHandler(void)
#elif ( (USART_RX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL5) || (USART_RX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL6) )
void DMA1_Channel4_5_6_7_IRQHandler(void)
#endif
{
	LPPUART_dma_rx_handler();

	return;
}

/**
  * @brief  Mapping of the CTS interrupt handler to the NVIC when using either PA0 or PD3
  *
  * @note	In all other cases, the mapping shall be done by the application as the IO may be shared
  * 		with others functionalities
  *
  * @param  None
  *
  * @retval None
  */
#if (USART_CTS_PIN_SELECTED == PA0)
void EXTI0_1_IRQHandler(void)
{
	LPPUART_wcts_handler();

	return;
}
#endif

void EXTI4_15_IRQHandler(void)
{
	#if ( (USART_CTS_PIN_SELECTED == PA6) || (USART_CTS_PIN_SELECTED == PA11) || (USART_CTS_PIN_SELECTED == PB13) )
	LPPUART_wcts_handler();
	#endif

	return;
}

/**
  * @brief  Call the interrupt handler of the TimerServer
  * @param  None
  * @retval None
  */
void RTC_IRQHandler(void)
{
	TIMER_RTC_Wakeup_Handler();

	return;
}

/**
  * @}
  */ 

/**
  * @}
  */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
